"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useBufferState = void 0;
const react_1 = require("react");
const buffering_1 = require("./buffering");
const CanUseRemotionHooks_1 = require("./CanUseRemotionHooks");
const useBufferState = () => {
    const canUseRemotionHooks = (0, react_1.useContext)(CanUseRemotionHooks_1.CanUseRemotionHooks);
    if (!canUseRemotionHooks) {
        if (typeof window !== 'undefined' && window.remotion_isPlayer) {
            throw new Error(`useCurrentFrame can only be called inside a component that was passed to <Player>. See: https://www.remotion.dev/docs/player/examples`);
        }
        throw new Error(`useCurrentFrame() can only be called inside a component that was registered as a composition. See https://www.remotion.dev/docs/the-fundamentals#defining-compositions`);
    }
    const buffer = (0, react_1.useContext)(buffering_1.BufferingContextReact);
    if (!buffer) {
        throw new Error('BufferingContextReact was unexpectedly not found. Most likely your Remotion versions are mismatching.');
    }
    return (0, react_1.useMemo)(() => ({
        delayPlayback: () => {
            const { unblock } = buffer.addBlock({
                id: String(Math.random()),
            });
            return { unblock };
        },
    }), [buffer]);
};
exports.useBufferState = useBufferState;
